[−][src]Struct rocket_auth_login::authorization::LoginCont
Fields
form: T
Methods
impl<T: AuthorizeForm + Clone> LoginCont<T>[src]
impl<T: AuthorizeForm + Clone> LoginCont<T>Trait Implementations
impl<T: Clone + AuthorizeForm> Clone for LoginCont<T>[src]
impl<T: Clone + AuthorizeForm> Clone for LoginCont<T>fn clone(&self) -> LoginCont<T>[src]
fn clone(&self) -> LoginCont<T>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl<T: Debug + AuthorizeForm> Debug for LoginCont<T>[src]
impl<T: Debug + AuthorizeForm> Debug for LoginCont<T>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<'f, A: AuthorizeForm> FromForm<'f> for LoginCont<A>[src]
impl<'f, A: AuthorizeForm> FromForm<'f> for LoginCont<A>#Collecting Login Form Data
If your login form requires more than just a username and password the
extras parameter, in AuthorizeForm::new_form(user, pass, extras), holds
all other fields in a HashMap<String, String> to allow processing any
field that was submitted. The username and password are separate because
those are universal fields.
Custom Username/Password Field Names
By default the function will look for a username and a password field.
If your form does not use those particular names you can always use the
extras HashMap to retrieve the username and password when using different
input box names. The function will return Ok() even if no username or
password was entered, this is to allow custom field names to be accessed
and authenticated by the authenticate() method.